##  Overview of Microsoft Teams Users
The Users tab enables you to view the list of all users who have installed the SAP LeanIX App. Administrators can access this tab by navigating to Administration > Integration > Configure (Microsoft Teams).
![Overview of SAP LeanIX App Users](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27522d877a4410149e36c930f503c3df_LowRes.png)
Overview of SAP LeanIX App Users
